@@ -27,13 +27,9 @@
 #include <gio/gio.h>
 
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
 #include <gtk/gtk.h>
 
 #include <cairo.h>
-#include <cairo-xlib.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include "gnome-bg.h"
@@ -65,10 +61,7 @@ enum {
 
 static guint signals[NUMBER_OF_SIGNALS] = { 0 };
 
-G_DEFINE_TYPE (GnomeBGCrossfade, gnome_bg_crossfade, G_TYPE_OBJECT)
-#define GNOME_BG_CROSSFADE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o),\
-			                   GNOME_TYPE_BG_CROSSFADE,\
-			                   GnomeBGCrossfadePrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeBGCrossfade, gnome_bg_crossfade, G_TYPE_OBJECT)
 
 static void
 gnome_bg_crossfade_set_property (GObject      *object,
@@ -195,14 +188,12 @@ gnome_bg_crossfade_class_init (GnomeBGCrossfadeClass *fade_class)
 					  G_SIGNAL_RUN_LAST, 0, NULL, NULL,
 					  g_cclosure_marshal_VOID__OBJECT,
 					  G_TYPE_NONE, 1, G_TYPE_OBJECT);
-
-	g_type_class_add_private (gobject_class, sizeof (GnomeBGCrossfadePrivate));
 }
 
 static void
 gnome_bg_crossfade_init (GnomeBGCrossfade *fade)
 {
-	fade->priv = GNOME_BG_CROSSFADE_GET_PRIVATE (fade);
+	fade->priv = gnome_bg_crossfade_get_instance_private (fade);
 
 	fade->priv->fading_surface = NULL;
 	fade->priv->end_surface = NULL;
@@ -370,34 +361,11 @@ animations_are_disabled (GnomeBGCrossfade *fade)
 	return !are_enabled;
 }
 
-static void
-send_root_property_change_notification (GnomeBGCrossfade *fade)
-{
-        long zero_length_pixmap;
-
-        /* We do a zero length append to force a change notification,
-         * without changing the value */
-        XChangeProperty (GDK_WINDOW_XDISPLAY (fade->priv->window),
-                         GDK_WINDOW_XID (fade->priv->window),
-                         gdk_x11_get_xatom_by_name ("_XROOTPMAP_ID"),
-                         XA_PIXMAP, 32, PropModeAppend,
-                         (guchar *) &zero_length_pixmap, 0);
-}
-
 static void
 draw_background (GnomeBGCrossfade *fade)
 {
 	if (gdk_window_get_window_type (fade->priv->window) == GDK_WINDOW_ROOT) {
-                XClearArea (GDK_WINDOW_XDISPLAY (fade->priv->window),
-                            GDK_WINDOW_XID (fade->priv->window),
-                            0, 0,
-                            gdk_window_get_width (fade->priv->window),
-                            gdk_window_get_height (fade->priv->window),
-                            False);
-
-                send_root_property_change_notification (fade);
-
-		gdk_flush ();
+		g_warning ("Crossfade is not supported on ROOT window!");
 	} else {
 		gdk_window_invalidate_rect (fade->priv->window, NULL, FALSE);
 		gdk_window_process_updates (fade->priv->window, FALSE);
