@@ -35,8 +35,6 @@
 #include "gnome-idle-monitor.h"
 #include "meta-dbus-idle-monitor.h"
 
-#define GNOME_IDLE_MONITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNOME_TYPE_IDLE_MONITOR, GnomeIdleMonitorPrivate))
-
 G_STATIC_ASSERT(sizeof(unsigned long) == sizeof(gpointer));
 
 struct _GnomeIdleMonitorPrivate
@@ -47,8 +45,6 @@ struct _GnomeIdleMonitorPrivate
 	int                  name_watch_id;
 	GHashTable          *watches;
 	GHashTable          *watches_by_upstream_id;
-	GdkDevice           *device;
-	gchar               *path;
 };
 
 typedef struct
@@ -64,15 +60,6 @@ typedef struct
 	guint64                   timeout_msec;
 } GnomeIdleMonitorWatch;
 
-enum
-{
-	PROP_0,
-	PROP_DEVICE,
-	PROP_LAST,
-};
-
-static GParamSpec *obj_props[PROP_LAST];
-
 static void gnome_idle_monitor_initable_iface_init (GInitableIface *iface);
 static void gnome_idle_monitor_remove_watch_internal (GnomeIdleMonitor *monitor,
 						      guint             id);
@@ -81,9 +68,12 @@ static void add_idle_watch (GnomeIdleMonitor *, GnomeIdleMonitorWatch *);
 static void add_active_watch (GnomeIdleMonitor *, GnomeIdleMonitorWatch *);
 
 G_DEFINE_TYPE_WITH_CODE (GnomeIdleMonitor, gnome_idle_monitor, G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GnomeIdleMonitor)
 			 G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
 						gnome_idle_monitor_initable_iface_init))
 
+#define IDLE_MONITOR_PATH "/org/gnome/Mutter/IdleMonitor/Core"
+
 static void
 on_watch_fired (MetaDBusIdleMonitor *proxy,
 		guint                upstream_id,
@@ -171,57 +161,10 @@ gnome_idle_monitor_dispose (GObject *object)
 	g_clear_object (&monitor->priv->om);
 	g_clear_pointer (&monitor->priv->watches, g_hash_table_destroy);
 	g_clear_pointer (&monitor->priv->watches_by_upstream_id, g_hash_table_destroy);
-	g_clear_object (&monitor->priv->device);
-	g_clear_pointer (&monitor->priv->path, g_free);
 
 	G_OBJECT_CLASS (gnome_idle_monitor_parent_class)->dispose (object);
 }
 
-static void
-gnome_idle_monitor_get_property (GObject    *object,
-				 guint       prop_id,
-				 GValue     *value,
-				 GParamSpec *pspec)
-{
-	GnomeIdleMonitor *monitor = GNOME_IDLE_MONITOR (object);
-	switch (prop_id)
-	{
-	case PROP_DEVICE:
-		g_value_set_object (value, monitor->priv->device);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-static void
-gnome_idle_monitor_set_property (GObject      *object,
-				 guint         prop_id,
-				 const GValue *value,
-				 GParamSpec   *pspec)
-{
-	GnomeIdleMonitor *monitor = GNOME_IDLE_MONITOR (object);
-	switch (prop_id)
-	{
-	case PROP_DEVICE:
-		monitor->priv->device = g_value_dup_object (value);
-
-		g_free (monitor->priv->path);
-		if (monitor->priv->device) {
-			monitor->priv->path = g_strdup_printf ("/org/gnome/Mutter/IdleMonitor/Device%d",
-							       gdk_x11_device_get_id (monitor->priv->device));
-		} else {
-			monitor->priv->path = g_strdup ("/org/gnome/Mutter/IdleMonitor/Core");
-		}
-
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
 static void
 add_known_watch (gpointer key,
 		 gpointer value,
@@ -261,7 +204,7 @@ on_object_added (GDBusObjectManager	*manager,
 {
 	GnomeIdleMonitor *monitor = user_data;
 
-	if (!g_str_equal (monitor->priv->path, g_dbus_object_get_object_path (object)))
+	if (!g_str_equal (IDLE_MONITOR_PATH, g_dbus_object_get_object_path (object)))
 		return;
 
 	connect_proxy (object, monitor);
@@ -275,7 +218,7 @@ get_proxy (GnomeIdleMonitor *monitor)
 	GDBusObject *object;
 
 	object = g_dbus_object_manager_get_object (G_DBUS_OBJECT_MANAGER (monitor->priv->om),
-						   monitor->priv->path);
+						   IDLE_MONITOR_PATH);
 	if (object) {
 		connect_proxy (object, monitor);
 		g_object_unref (object);
@@ -379,29 +322,12 @@ gnome_idle_monitor_class_init (GnomeIdleMonitorClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->dispose = gnome_idle_monitor_dispose;
-	object_class->get_property = gnome_idle_monitor_get_property;
-	object_class->set_property = gnome_idle_monitor_set_property;
-
-	/**
-	 * GnomeIdleMonitor:device:
-	 *
-	 * The device to listen to idletime on.
-	 */
-	obj_props[PROP_DEVICE] =
-		g_param_spec_object ("device",
-				     "Device",
-				     "The device to listen to idletime on",
-				     GDK_TYPE_DEVICE,
-				     G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
-	g_object_class_install_property (object_class, PROP_DEVICE, obj_props[PROP_DEVICE]);
-
-	g_type_class_add_private (klass, sizeof (GnomeIdleMonitorPrivate));
 }
 
 static void
 gnome_idle_monitor_init (GnomeIdleMonitor *monitor)
 {
-	monitor->priv = GNOME_IDLE_MONITOR_GET_PRIVATE (monitor);
+	monitor->priv = gnome_idle_monitor_get_instance_private (monitor);
 
 	monitor->priv->watches = g_hash_table_new_full (NULL,
 							NULL,
@@ -416,8 +342,7 @@ gnome_idle_monitor_init (GnomeIdleMonitor *monitor)
  * gnome_idle_monitor_new:
  *
  * Returns: a new #GnomeIdleMonitor that tracks the server-global
- * idletime for all devices. To track device-specific idletime,
- * use gnome_idle_monitor_new_for_device().
+ * idletime for all devices.
  */
 GnomeIdleMonitor *
 gnome_idle_monitor_new (void)
@@ -425,33 +350,6 @@ gnome_idle_monitor_new (void)
 	return GNOME_IDLE_MONITOR (g_initable_new (GNOME_TYPE_IDLE_MONITOR, NULL, NULL, NULL));
 }
 
-/**
- * gnome_idle_monitor_new_for_device:
- * @device: A #GdkDevice to get the idle time for.
- * @error: A pointer to a #GError or %NULL.
- *
- * Returns: a new #GnomeIdleMonitor that tracks the device-specific
- * idletime for @device. If device-specific idletime is not available,
- * %NULL is returned, and @error is set. To track server-global
- * idletime for all devices, use gnome_idle_monitor_new(). This function
- * only works under X11, not under Wayland and will return an error.
- */
-GnomeIdleMonitor *
-gnome_idle_monitor_new_for_device (GdkDevice  *device,
-				   GError    **error)
-{
-#if defined(GDK_WINDOWING_WAYLAND)
-	if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ())) {
-		g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-				     "Per-device idle monitors not supported under Wayland");
-		return NULL;
-	}
-#endif
-
-	return GNOME_IDLE_MONITOR (g_initable_new (GNOME_TYPE_IDLE_MONITOR, NULL, error,
-						   "device", device, NULL));
-}
-
 static GnomeIdleMonitorWatch *
 make_watch (GnomeIdleMonitor          *monitor,
 	    guint64                    timeout_msec,
